Change Log
============

0.0.2 (May 16, 2023)
----------------------
- Can now display information of multiple variables in a table
- Support torch, tensorflow ans sparse

0.0.1 (May 22, 2022)
----------------------
- First Release